@@ -1,6 +1,6 @@
 package Map::Tube::Delhi::Line::Blue;
 $Map::Tube::Delhi::Line::Blue::AUTHORITY = 'cpan:MANWAR';
-$Map::Tube::Delhi::Line::Blue::VERSION = '0.44';
+$Map::Tube::Delhi::Line::Blue::VERSION = '0.45';
 use 5.006;
 use strict; use warnings;
 
@@ -10,7 +10,7 @@ Map::Tube::Delhi::Line::Blue - Delhi Metro Map: Blue Line.
 
 =head1 VERSION
 
-version 0.44
+version 0.45
 
 =head1 DESCRIPTION
 
@@ -78,23 +78,26 @@ Delhi Metro Map: Blue Line.
 
 =over 2
 
-=item * The station "Dwarka Sector 21" is also part of L<Orange Line|Map::Tube::Delhi::Line::Orange>.
+=item * The station "Dwarka Sector 21" is also part of
+          L<Orange Line|Map::Tube::Delhi::Line::Orange>.
 
-=item * The station "Kirti Nagar" is also part of L<Green Line|Map::Tube::Delhi::Line::Green>.
+=item * The station "Kirti Nagar" is also part of
+          L<Green Line|Map::Tube::Delhi::Line::Green>.
 
-=item * The station "Rajiv Chowk" is also part of L<Yellow Line|Map::Tube::Delhi::Line::Yellow>.
+=item * The station "Rajiv Chowk" is also part of
+          L<Yellow Line|Map::Tube::Delhi::Line::Yellow>.
 
 =back
 
 =head1 MAP
 
-Delhi Metro Map: L<Blue Line|https://raw.githubusercontent.com/Manwar/Map-Tube-Delhi/master/maps/Blue.png>
+Delhi Metro Map: L<Blue Line|https://raw.githubusercontent.com/manwar/Map-Tube-Delhi/master/maps/Blue.png>
 map generated by plugin L<Map::Tube::Plugin::Graph>.
 
 =begin html
 
-<a href = "https://raw.githubusercontent.com/Manwar/Map-Tube-Delhi/master/maps/Blue.png">
-<img src    = "https://raw.githubusercontent.com/Manwar/Map-Tube-Delhi/master/maps/Blue.png"
+<a href = "https://raw.githubusercontent.com/manwar/Map-Tube-Delhi/master/maps/Blue.png">
+<img src    = "https://raw.githubusercontent.com/manwar/Map-Tube-Delhi/master/maps/Blue.png"
      alt    = "Delhi Metro Map: Blue Line"
      width  = "250px"
      height = "600px"/>
