@@ -1,6 +1,6 @@
 package Map::Tube::Delhi::Line::Yellow;
 $Map::Tube::Delhi::Line::Yellow::AUTHORITY = 'cpan:MANWAR';
-$Map::Tube::Delhi::Line::Yellow::VERSION = '0.44';
+$Map::Tube::Delhi::Line::Yellow::VERSION = '0.45';
 use 5.006;
 use strict; use warnings;
 
@@ -10,16 +10,14 @@ Map::Tube::Delhi::Line::Yellow - Delhi Metro Map: Yellow Line.
 
 =head1 VERSION
 
-version 0.44
+version 0.45
 
 =head1 DESCRIPTION
 
 Delhi Metro Map: Yellow Line.
 
     +-----------------------+---------------------------------------------------+
-    |                       |                                                   |
     | Station Name          | Linked To                                         |
-    |                       |                                                   |
     +-----------------------+---------------------------------------------------+
     | HUDA City Centre      | IFFCO Chowk                                       |
     | IFFCO Chowk           | M G Road, HUDA City Centre                        |
@@ -61,25 +59,29 @@ Delhi Metro Map: Yellow Line.
 
 =over 2
 
-=item * The station "Central Secretariate" is also part of L<Violet Line|Map::Tube::Delhi::Line::Violet>.
+=item * The station "Central Secretariate" is also part of
+          L<Violet Line|Map::Tube::Delhi::Line::Violet>.
 
-=item * The station "Rajiv Chowk" is also part of L<Blue Line|Map::Tube::Delhi::Line::Blue>.
+=item * The station "Rajiv Chowk" is also part of
+          L<Blue Line|Map::Tube::Delhi::Line::Blue>.
 
-=item * The station "New Delhi" is also part of L<Orange Line|Map::Tube::Delhi::Line::Orange>.
+=item * The station "New Delhi" is also part of
+          L<Orange Line|Map::Tube::Delhi::Line::Orange>.
 
-=item * The station "Kashmere Gate" is also part of L<Red Line|Map::Tube::Delhi::Line::Red>.
+=item * The station "Kashmere Gate" is also part of
+          L<Red Line|Map::Tube::Delhi::Line::Red>.
 
 =back
 
 =head1 MAP
 
-Delhi Metro Map: L<Yellow Line|https://raw.githubusercontent.com/Manwar/Map-Tube-Delhi/master/maps/Yellow.png>
+Delhi Metro Map: L<Yellow Line|https://raw.githubusercontent.com/manwar/Map-Tube-Delhi/master/maps/Yellow.png>
 map generated by plugin L<Map::Tube::Plugin::Graph>.
 
 =begin html
 
-<a href = "https://raw.githubusercontent.com/Manwar/Map-Tube-Delhi/master/maps/Yellow.png">
-<img src    = "https://raw.githubusercontent.com/Manwar/Map-Tube-Delhi/master/maps/Yellow.png"
+<a href = "https://raw.githubusercontent.com/manwar/Map-Tube-Delhi/master/maps/Yellow.png">
+<img src    = "https://raw.githubusercontent.com/manwar/Map-Tube-Delhi/master/maps/Yellow.png"
      alt    = "Delhi Metro Map: Yellow Line"
      width  = "350px"
      height = "500px"/>
